@@ -1,6 +1,6 @@
 #   save-history.rb -
 #   	$Release Version: 0.9.6$
-#   	$Revision: 25189 $
+#   	$Revision: 39049 $
 #   	by Keiju ISHITSUKA(keiju@ruby-lang.org)
 #
 # --
@@ -11,21 +11,31 @@
 require "readline"
 
 module IRB
-  module HistorySavingAbility
-    @RCS_ID='-$Id: save-history.rb 25189 2009-10-02 12:04:37Z akr $-'
+  module HistorySavingAbility # :nodoc:
+    @RCS_ID='-$Id: save-history.rb 39049 2013-02-04 23:04:09Z zzak $-'
   end
 
   class Context
-    def init_save_history
+    def init_save_history# :nodoc:
       unless (class<<@io;self;end).include?(HistorySavingAbility)
 	@io.extend(HistorySavingAbility)
       end
     end
 
+    # A copy of the default <code>IRB.conf[:SAVE_HISTORY]</code>
     def save_history
       IRB.conf[:SAVE_HISTORY]
     end
 
+    # Sets <code>IRB.conf[:SAVE_HISTORY]</code> to the given +val+ and calls
+    # #init_save_history with this context.
+    #
+    # Will store the number of +val+ entries of history in the #history_file
+    #
+    # Add the following to your +.irbrc+ to change the number of history
+    # entries stored to 1000:
+    #
+    #     IRB.conf[:SAVE_HISTORY] = 1000
     def save_history=(val)
       IRB.conf[:SAVE_HISTORY] = val
       if val
@@ -35,16 +45,18 @@ module IRB
       end
     end
 
+    # A copy of the default <code>IRB.conf[:HISTORY_FILE]</code>
     def history_file
       IRB.conf[:HISTORY_FILE]
     end
 
+    # Set <code>IRB.conf[:HISTORY_FILE]</code> to the given +hist+.
     def history_file=(hist)
       IRB.conf[:HISTORY_FILE] = hist
     end
   end
 
-  module HistorySavingAbility
+  module HistorySavingAbility # :nodoc:
     include Readline
 
 #     def HistorySavingAbility.create_finalizer
@@ -87,7 +99,18 @@ module IRB
 	  history_file = File.expand_path(history_file)
 	end
 	history_file = IRB.rc_file("_history") unless history_file
-	open(history_file, 'w' ) do |f|
+
+	# Change the permission of a file that already exists[BUG #7694]
+	begin
+	  if File.stat(history_file).mode & 066 != 0
+	    File.chmod(0600, history_file)
+	  end
+	rescue Errno::ENOENT
+	rescue
+	  raise
+	end
+
+	open(history_file, 'w', 0600 ) do |f|
 	  hist = HISTORY.to_a
 	  f.puts(hist[-num..-1] || hist)
 	end
