@@ -1,17 +1,18 @@
 #
-#   irb/workspace-binding.rb - 
-#   	$Release Version: 0.9.5$
-#   	$Revision: 1.5.2.2 $
-#   	$Date: 2005/04/19 19:24:57 $
+#   irb/workspace-binding.rb -
+#   	$Release Version: 0.9.6$
+#   	$Revision: 43933 $
 #   	by Keiju ISHITSUKA(keiju@ruby-lang.org)
 #
 # --
 #
-#   
 #
-module IRB
+#
+module IRB # :nodoc:
   class WorkSpace
-    # create new workspace. set self to main if specified, otherwise
+    # Creates a new workspace.
+    #
+    # set self to main if specified, otherwise
     # inherit main from TOPLEVEL_BINDING.
     def initialize(*main)
       if main[0].kind_of?(Binding)
@@ -22,7 +23,7 @@ module IRB
 	case IRB.conf[:CONTEXT_MODE]
 	when 0	# binding in proc on TOPLEVEL_BINDING
 	  @binding = eval("proc{binding}.call",
-		      TOPLEVEL_BINDING, 
+		      TOPLEVEL_BINDING,
 		      __FILE__,
 		      __LINE__)
 	when 1	# binding in loaded file
@@ -38,8 +39,8 @@ EOF
 	when 2	# binding in loaded file(thread use)
 	  unless defined? BINDING_QUEUE
 	    require "thread"
-	    
-	    IRB.const_set("BINDING_QUEUE", SizedQueue.new(1))
+
+	    IRB.const_set(:BINDING_QUEUE, SizedQueue.new(1))
 	    Thread.abort_on_exception = true
 	    Thread.start do
 	      eval "require \"irb/ws-for-case-2\"", TOPLEVEL_BINDING, __FILE__, __LINE__
@@ -48,9 +49,9 @@ EOF
 	  end
 	  @binding = BINDING_QUEUE.pop
 
-	when 3	# binging in function on TOPLEVEL_BINDING(default)
-	  @binding = eval("def irb_binding; binding; end; irb_binding",
-		      TOPLEVEL_BINDING, 
+	when 3	# binding in function on TOPLEVEL_BINDING(default)
+	  @binding = eval("def irb_binding; private; binding; end; irb_binding",
+		      TOPLEVEL_BINDING,
 		      __FILE__,
 		      __LINE__ - 3)
 	end
@@ -64,7 +65,7 @@ EOF
 	when Module
 	  @binding = eval("IRB.conf[:__MAIN__].module_eval('binding', __FILE__, __LINE__)", @binding, __FILE__, __LINE__)
 	else
-	  begin 
+	  begin
 	    @binding = eval("IRB.conf[:__MAIN__].instance_eval('binding', __FILE__, __LINE__)", @binding, __FILE__, __LINE__)
 	  rescue TypeError
 	    IRB.fail CantChangeBinding, @main.inspect
@@ -74,13 +75,17 @@ EOF
       eval("_=nil", @binding)
     end
 
+    # The Binding of this workspace
     attr_reader :binding
+    # The top-level workspace of this context, also available as
+    # <code>IRB.conf[:__MAIN__]</code>
     attr_reader :main
 
+    # Evaluate the given +statements+ within the  context of this workspace.
     def evaluate(context, statements, file = __FILE__, line = __LINE__)
       eval(statements, @binding, file, line)
     end
-  
+
     # error message manipulator
     def filter_backtrace(bt)
       case IRB.conf[:CONTEXT_MODE]
@@ -94,9 +99,11 @@ EOF
 	end
       when 2
 	return nil if bt =~ /irb\/.*\.rb/
+	return nil if bt =~ /irb\.rb/
       when 3
 	return nil if bt =~ /irb\/.*\.rb/
-	bt.sub!(/:\s*in `irb_binding'/){""} 
+	return nil if bt =~ /irb\.rb/
+	bt = bt.sub(/:\s*in `irb_binding'/, '')
       end
       bt
     end
