@@ -3,8 +3,8 @@
 # changes made to this file will be lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION == "2.1.6" or
-    raise "ruby lib version (2.1.6) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION == "2.1.8" or
+    raise "ruby lib version (2.1.8) doesn't match executable version (#{RUBY_VERSION})"
 
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.1/mips64el-openbsd")
   DESTDIR = '' unless defined? DESTDIR
@@ -13,8 +13,8 @@ module RbConfig
   CONFIG["MAJOR"] = "2"
   CONFIG["MINOR"] = "1"
   CONFIG["TEENY"] = "0"
-  CONFIG["PATCHLEVEL"] = "336"
-  CONFIG["INSTALL"] = '/usr/obj/ports/ruby-2.1.6/bin/install -c '
+  CONFIG["PATCHLEVEL"] = "440"
+  CONFIG["INSTALL"] = '/usr/ports/pobj/ruby-2.1.8/bin/install -c '
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "ruby21"
@@ -77,7 +77,7 @@ module RbConfig
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_SO_NAME).so"
-  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.1.1"
+  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.1.2"
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["rubyw_install_name"] = ""
@@ -142,9 +142,9 @@ module RbConfig
   CONFIG["DTRACE"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/usr/obj/ports/ruby-2.1.6/bin/install -c  -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ports/ruby-2.1.6/bin/install -c  -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ports/ruby-2.1.6/bin/install -c -s  -m 755"
+  CONFIG["INSTALL_DATA"] = "/usr/ports/pobj/ruby-2.1.8/bin/install -c  -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/usr/ports/pobj/ruby-2.1.8/bin/install -c  -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/usr/ports/pobj/ruby-2.1.8/bin/install -c -s  -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["NM"] = "nm"
@@ -177,23 +177,23 @@ module RbConfig
   CONFIG["NACL_SDK_VARIANT"] = ""
   CONFIG["NACL_SDK_ROOT"] = ""
   CONFIG["NACL_TOOLCHAIN"] = ""
-  CONFIG["target_os"] = "openbsd5.8"
+  CONFIG["target_os"] = "openbsd5.9"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "mips64el"
-  CONFIG["target"] = "mips64el-unknown-openbsd5.8"
-  CONFIG["host_os"] = "openbsd5.8"
+  CONFIG["target"] = "mips64el-unknown-openbsd5.9"
+  CONFIG["host_os"] = "openbsd5.9"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "mips64el"
-  CONFIG["host"] = "mips64el-unknown-openbsd5.8"
+  CONFIG["host"] = "mips64el-unknown-openbsd5.9"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd5.8"
+  CONFIG["build_os"] = "openbsd5.9"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "mips64el"
-  CONFIG["build"] = "mips64el-unknown-openbsd5.8"
-  CONFIG["RUBY_RELEASE_DATE"] = "2015-04-13"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.1.6"
+  CONFIG["build"] = "mips64el-unknown-openbsd5.9"
+  CONFIG["RUBY_RELEASE_DATE"] = "2015-12-16"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.1.8"
   CONFIG["target_alias"] = ""
   CONFIG["host_alias"] = ""
   CONFIG["build_alias"] = ""
